@@ -67,7 +67,7 @@ class pfdo_mgz2image(pfdo.pfdo):
         """
         This method does not actually read in any files, but
         exists to preserve the list of files associated with a
-        given input directory. 
+        given input directory.
 
         By preserving and returning this file list, the next
         callback function in this pipeline is able to receive an
@@ -165,7 +165,7 @@ class pfdo_mgz2image(pfdo.pfdo):
         l_fileProbed        : list  = []
         d_inputReadCallback : dict  = {}
         d_convert           : dict  = {}
-        
+
 
         for k, v in kwargs.items():
             if k == 'path':         str_path    = v
@@ -178,25 +178,30 @@ class pfdo_mgz2image(pfdo.pfdo):
 
         # pudb.set_trace()
         mgz2image_args                  = self.args.copy()
-        
         # print(at_data)
 
         for str_file in l_fileToAnalyze_determine(l_fileProbed):
             mgz2image_args['inputDir']      = str_path
             mgz2image_args['inputFile']     = str_file
             mgz2image_args['outputDir']     = str_path.replace(
-                                                self.args['inputDir'], 
+                                                self.args['inputDir'],
                                                 self.args['outputDir']
                                             )
 
             mgz2image_args['outputDir'] = os.path.join(mgz2image_args['outputDir'], str_file)
-            os.mkdir(mgz2image_args['outputDir'])
+            other.mkdir(mgz2image_args['outputDir'])
 
-            mgz2image_args['saveImages']    = self.args['saveImages']  
-            mgz2image_args['skipAllLabels'] = self.args['skipAllLabels']  
+            mgz2image_args['saveImages']    = self.args['saveImages']
+            mgz2image_args['skipAllLabels'] = self.args['skipAllLabels']
 
             mgz2image_ns    = Namespace(**mgz2image_args)
-            imgConverter    = mgz2imgslices.object_factoryCreate(mgz2image_ns).C_convert
+
+            # Note that the imgConverter has an implicit assumption on an existing
+            # /usr/src/FreeSurferColorLUT.txt!
+            try:
+                imgConverter    = mgz2imgslices.object_factoryCreate(mgz2image_ns).C_convert
+            except Exception as e:
+                self.dp.qprint(e, comms = 'error', level = 0)
 
             # At time of dev, the `imgConverter.run()` does not return anything.
             imgConverter.run()
@@ -285,7 +290,7 @@ class pfdo_mgz2image(pfdo.pfdo):
 
         if b_timerStart:    other.tic()
 
-        pudb.set_trace()
+        # pudb.set_trace()
         d_pfdo          = super().run(
                             JSONprint   = False,
                             timerStart  = False
